# A module containing several functions to compute the phase reset index
# Nebojsa Bozanic <bozanic@stanford.edu> Copyright 2020
# Distributed under the BSD License

import phasereset

def test():

 return 0